MoWAKi - Python utilities
#########################

This package provides several common utilities for MoWAKi_ apps.

.. _MoWAKi: https://www.mowaki.org


Storage
=======

Provides a common abstraction for file storage.

Currently supports storing data in:

- memory (mostly for testing)
- local filesystem (mostly for local development)
- s3 buckets
